from enum import IntFlag


class Result(IntFlag):
    SUCCESS = 1
    FAILURE = 2
    EXIST = 4
    WAIT = 8
    UNKNOWN = 16

    def is_success(self) -> bool:
        return bool(self & Result.SUCCESS)

    def is_failure(self) -> bool:
        return bool(self & Result.FAILURE)

    def is_exist(self) -> bool:
        return bool(self & Result.EXIST)

    def is_wait(self) -> bool:
        return bool(self & Result.WAIT)

    def __str__(self) -> str:
        return self.name.lower()



DEFAULT_HEADERS = {
    'User-Agent': 'Wget/1.12 (linux-gnu)',
    'Content-Encoding': 'identity',
    'Accept-Encoding': 'identity'
}
DEFAULT_CHUNK_SIZE = 1024 * 1024
DEFAULT_SLICED_CHUNK_SIZE = 100 * 1024 * 1024
DEFAULT_TIMEOUT = 60
DEFAULT_MAX_RETRY = 3
DEFAULT_RETRY_DELAY = 1
DEFAULT_SLICED_FILE_SUFFIX = '.ydstf'
